[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](LICENSE)
[![Build Status](https://travis-ci.org/polyaxon/polyaxon-k8s.svg?branch=master)](https://travis-ci.org/polyaxon/polyaxon-k8s)
[![PyPI version](https://badge.fury.io/py/polyaxon-k8s.svg)](https://badge.fury.io/py/polyaxon-k8s)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/ef56c1d0ed7a413a8303f1814b53d453)](https://www.codacy.com/app/polyaxon/polyaxon-k8s?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=polyaxon/polyaxon-k8s&amp;utm_campaign=Badge_Grade)
[![Slack](https://img.shields.io/badge/chat-on%20slack-aadada.svg?logo=slack&longCache=true)](https://join.slack.com/t/polyaxon/shared_invite/enQtMzQ0ODc2MDg1ODc0LWY2ZTdkMTNmZjBlZmRmNjQxYmYwMTBiMDZiMWJhODI2ZTk0MDU4Mjg5YzA5M2NhYzc5ZjhiMjczMDllYmQ2MDg)

# Polyaxon-k8s

Polyaxon Kubernetes managers, utils and resources.

## License

[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fpolyaxon%2Fpolyaxon-k8s.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fpolyaxon%2Fpolyaxon-k8s?ref=badge_large)
